Crate polkadot_node_core_provisioner

Crate polkadot_node_core_provisioner 

The provisioner is responsible for assembling a relay chain block from a set of available parachain candidates of its choice.

Structs

Metrics
Provisioner metrics.
PerRelayParent
A per-relay-parent state for the provisioning subsystem.
ProvisionerSubsystem
The provisioner subsystem.